@@ -159,6 +159,10 @@
         <source>Service has not been started</source>
         <translation>Der Dienst wurde nicht gestartet</translation>
     </message>
+    <message>
+        <source>Recording permissions are not available</source>
+        <translation>Berechtigung zur Aufnahme fehlt</translation>
+    </message>
 </context>
 <context>
     <name>CameraBinSession</name>
@@ -272,18 +276,6 @@
         <source>Error parsing playlist at line[%1]:%2</source>
         <translation>Fehler beim Auswerten der Abspielliste bei Zeile [%1]:%2</translation>
     </message>
-    <message>
-        <source>File%1</source>
-        <translation>Datei%1</translation>
-    </message>
-    <message>
-        <source>Title%1</source>
-        <translation>Titel%1</translation>
-    </message>
-    <message>
-        <source>Length%1</source>
-        <translation>Länge%1</translation>
-    </message>
 </context>
 <context>
     <name>QAndroidAudioEncoderSettingsControl</name>
@@ -302,6 +294,10 @@
 </context>
 <context>
     <name>QAndroidCameraSession</name>
+    <message>
+        <source>Camera cannot be started without a viewfinder.</source>
+        <translation>Die Kamera kann nicht ohne Sucher gestartet werden.</translation>
+    </message>
     <message>
         <source>Camera not ready</source>
         <translation>Kamera nicht bereit</translation>
